/*

  Ioctl() definitions for BCI-2xxx driver.

  Copyright (C) 2000-2006 by Digby's Bitpile, Inc.  All rights reserved.

  03/11/2000	JMBW	Created.

*/

#include <linux/ioctl.h>	/* _IO* macros */

/* structure used as ioctl() argument for I/O page write requests */
struct iopreq {
	unsigned int addr;	/* address to write */
	unsigned short data;	/* data to write (correct byte if DATOB) */
};

struct umrreq {
	unsigned short reg;	/* UMR number, 0-31 */
	unsigned int data;	/* UMR value, 22 bits (LSB = 0) */
};

struct brabrb {
	unsigned char bra;	/* actual BR level of BRA, 4-6 (BCI-200x) */
	unsigned char brb;	/* actual BR level of BRB, 5-7 (BCI-200x) */
};

struct dmareg {
	void *addr;		/* start of page-aligned memory region */
	unsigned int len;	/* length in bytes (normally <= 4088 KB) */
};

#define BAMAGIC 0xBA	/* ioctl() function code magicnum */

#define BCIRST _IO(BAMAGIC,0)	/* issue reset pulse */
#define BCIOFFSET _IO(BAMAGIC,1) /* set offset of start of DMA buffer */
#define BCIREQS _IO(BAMAGIC,2)	/* obtain bitmap of BRs */
#define BCIGRANT _IO(BAMAGIC,3)	/* attempt to grant BR #argp */
#define BCIDATI _IO(BAMAGIC,4)	/* issue "data in" cycle */
#define BCIDATIP _IO(BAMAGIC,5)	/* issue "data in and pause" cycle */
#define BCIDATO _IOW(BAMAGIC,6,struct iopreq) /* "data out" cycle */
#define BCIDATOB _IOW(BAMAGIC,7,struct iopreq) /* "data out byte" cycle */
#define BCIUMAP _IO(BAMAGIC,8)	/* enable/disable Unibus map, if any */
#define BCIWUMR _IOW(BAMAGIC,9,struct umrreq) /* write to UMR */
#define BCIBRAB _IOW(BAMAGIC,10,struct brabrb) /* set BRA/BRB prio levels */
#define BCIDMA _IOW(BAMAGIC,11,struct dmareg) /* begin DMA to user memory */
